@@ -8,11 +8,12 @@ class ListField(BaseField):
     '''
     Field responsible for storing :py:class:`list`.
 
-    Usage::
+    Usage:
+
+    .. testcode:: modeling_fields
 
         posts = ListField(StringField())
 
-
     Available arguments (apart from those in `BaseField`):
 
     * `base_field` - ListField must be another field that describe the items in this list
